import logging
from immutable_views import DictView, ListView

from workspaces.system.enums import RemoteWorkflows
from workspaces.workflow.schema_interfaces import WorkflowRequestIF

logger = logging.getLogger(__name__)

"""
Class which creates immutable dictionary and list views containing capo properties required by remote executing workflows.
When a workflow is confirmed as able to run remotely, this should be updated if necessary
"""
wf_properties_list = DictView(
    {
        "general": [
            "edu.nrao.workspaces.WorkflowSettings.serviceUrl",
            "edu.nrao.workspaces.NotificationSettings.serviceUrl",
        ],
        "casa_requirements": [
            "edu.nrao.workspaces.ProcessingSettings.useCasa",
            "edu.nrao.archive.workflow.config.CasaVersions.homeForReprocessing",
        ],
    }
)


class ViewWorkflowCapoParameters:
    def __init__(self, wf_request: WorkflowRequestIF):
        self.request = wf_request

    @staticmethod
    def general_parameters() -> list:
        logger.info("Gathering general properties...")
        return wf_properties_list["general"]

    @staticmethod
    def casa_parameters() -> list:
        logger.info("Gathering CASA properties...")
        return wf_properties_list["casa_requirements"]

    def construct_view(self) -> ListView:
        wf = RemoteWorkflows(self.request.workflow_name)
        logger.info(wf)
        if wf == RemoteWorkflows.SECI:
            return ListView(self.general_parameters() + self.casa_parameters())
